---
name: portainer-agent-docs
description: Documentation and API references for Portainer agent
crawl_depth: 2
source_url: https://docs.portainer.io, https://api-docs.portainer.io
categories: [Documentation, Knowledge Base, Reference]
tags: [docs, reference, portainer-agent-docs, knowledge-base]
---

# Portainer Agent Docs Documentation

Documentation and API references for Portainer agent

**Original Sources**:
- [https://docs.portainer.io](https://docs.portainer.io)
- [https://api-docs.portainer.io](https://api-docs.portainer.io)

**Contains**: 474 markdown files with full folder structure (crawled at depth 2).
*Last updated: March 05, 2026*

## 📚 Table of Contents

- 📁 **index/**
  - 📁 **PortainerEE-API-2.39.0/**
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Sectionauthenticationauthentication](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0sectionAuthenticationAuthentication.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Sectionexecute Docker Requestsexecute Docker Requests](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0sectionExecute-Docker-requestsExecute-Docker-requests.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Sectionprivate Registryprivate Registry](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0sectionPrivate-RegistryPrivate-Registry.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Sectionsecuritysecurity](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0sectionSecuritySecurity.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagauthauth](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauthauth.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagauthoperationauthenticateuserauthenticate](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauthoperationAuthenticateUserAuthenticate.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagauthoperationlogoutlogout](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauthoperationLogoutLogout.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagauthoperationvalidateoauthauthenticate With Oauth](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauthoperationValidateOAuthAuthenticate-with-OAuth.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagauto Updatesauto Updates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauto_updatesauto_updates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagauto Updatesoperationautoupdatelistlist Auto Updates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauto_updatesoperationAutoUpdateListList-auto-updates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagbackupbackup](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupbackup.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagbackupoperationbackupcreates An Archive With A System Data Snapshot That Could Be Used To Restore The System.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationBackupCreates-an-archive-with-a-system-data-snapshot-that-could-be-used-to-restore-the-system..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagbackupoperationbackupsettingsfetchfetch S3 Backup Settingsconfigurations](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationBackupSettingsFetchFetch-s3-backup-settingsconfigurations.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagbackupoperationbackupstatusfetchfetch The Status Of The Last Scheduled Backup Run](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationBackupStatusFetchFetch-the-status-of-the-last-scheduled-backup-run.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagbackupoperationbackuptos3Execute Backup To Aws S3 Bucket](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationBackupToS3Execute-backup-to-AWS-S3-Bucket.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagbackupoperationrestorefroms3Triggers A System Restore Using Details Of S3 Backup](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationRestoreFromS3Triggers-a-system-restore-using-details-of-s3-backup.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagbackupoperationrestoretriggers A System Restore Using Provided Backup File](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationRestoreTriggers-a-system-restore-using-provided-backup-file.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagbackupoperationupdates3Settingsupdates Stored S3 Backup Settings And Updates Running Cron Jobs As Needed](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationUpdateS3SettingsUpdates-stored-s3-backup-settings-and-updates-running-cron-jobs-as-needed.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialscloud Credentials](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialscloud_credentials.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationcreatecreate A Cloud Credential](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationCreateCreate-a-cloud-credential.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationgenerategenerate Ssh Keypair](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationGenerateGenerate-ssh-keypair.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationsharedgitcreatecreate Shared Git Credential](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitCreateCreate-Shared-Git-Credential.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationsharedgitdeletedelete Shared Git Credential](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitDeleteDelete-Shared-Git-Credential.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationsharedgitgetallget Shared Git Credentials](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitGetAllGet-Shared-Git-Credentials.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationsharedgitgetget Shared Git Credential](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitGetGet-Shared-Git-Credential.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationsharedgitupdateupdate A Shared Git Credential](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitUpdateUpdate-a-Shared-Git-Credential.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationcloudcredsdeletedelete A Cloud Credential](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationcloudCredsDeleteDelete-a-cloud-credential.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationcloudcredsgetbyidgetbyid Gets A Cloud Credential By Id](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationcloudCredsGetByIDgetByID-gets-a-cloud-credential-by-ID.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationcloudcredsupdateupdate A Cloud Credential](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationcloudCredsUpdateUpdate-a-cloud-credential.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcloud Credentialsoperationgetallgetall Cloud Credentials](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationgetAllgetAll-cloud-credentials.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatescustom Templates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatescustom_templates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplatecreatecreate A Custom Template  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateCreateCreate-a-custom-template--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplatecreatefilecreate A Custom Template](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateCreateFileCreate-a-custom-template.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplatecreaterepositorycreate A Custom Template](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateCreateRepositoryCreate-a-custom-template.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplatecreatestringcreate A Custom Template](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateCreateStringCreate-a-custom-template.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplatedeleteremove A Template](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateDeleteRemove-a-template.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplatefileget Template Stack File Content.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateFileGet-Template-stack-file-content..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplategitfetchfetch The Latest Config File Content Based On Custom Templates Git Repository Configuration](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateGitFetchFetch-the-latest-config-file-content-based-on-custom-templates-git-repository-configuration.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplateinspectinspect A Custom Template](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateInspectInspect-a-custom-template.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplatelistlist Available Custom Templates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateListList-available-custom-templates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagcustom Templatesoperationcustomtemplateupdateupdate A Template](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateUpdateUpdate-a-template.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockerdocker](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockerdocker.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationserviceimagestatusfetch Image Status For Service](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationServiceImageStatusFetch-image-status-for-service.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationcontainerimagestatusfetch Image Status For Container](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationcontainerImageStatusFetch-image-status-for-container.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationcontainersimagestatusclearclear Container Image Status Cache](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationcontainersImageStatusClearClear-container-image-status-cache.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationdockercontainergpusinspectfetch Container Gpus Data](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationdockerContainerGpusInspectFetch-container-gpus-data.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationdockerdashboardget Counters For The Dashboard](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationdockerDashboardGet-counters-for-the-dashboard.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationdockerimageslistfetch Images](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationdockerImagesListFetch-images.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationserviceimagestatusclearclear Service Image Status Cache](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationserviceImageStatusClearClear-service-image-status-cache.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationsnapshotcontainerinspectfetch Container From A Snapshot](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationsnapshotContainerInspectFetch-container-from-a-snapshot.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationsnapshotcontainerslistfetch Containers List From A Snapshot](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationsnapshotContainersListFetch-containers-list-from-a-snapshot.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationsnapshotinspectfetch Latest Snapshot Of Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationsnapshotInspectFetch-latest-snapshot-of-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagdockeroperationstacksimagestatusclearclear Stack Image Status Cache](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationstacksImageStatusClearClear-stack-image-status-cache.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Configsedge Configs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsedge_configs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Configsoperationedgeconfigcreatecreate An Edge Configuration](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigCreateCreate-an-Edge-Configuration.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Configsoperationedgeconfigdeletedelete An Edge Configuration](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigDeleteDelete-an-Edge-configuration.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Configsoperationedgeconfigfilesget The Files For An Edge Configuration](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigFilesGet-the-files-for-an-Edge-configuration.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Configsoperationedgeconfiginspectinspect An Edge Configuration](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigInspectInspect-an-Edge-configuration.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Configsoperationedgeconfiglistlist Available Edge Configurations](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigListList-available-Edge-Configurations.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Configsoperationedgeconfigstateupdate The State Of An Edge Configuration](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigStateUpdate-the-state-of-an-Edge-configuration.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Configsoperationedgeconfigupdateupdate An Edge Configuration](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigUpdateUpdate-an-Edge-Configuration.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Groupsedge Groups](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsedge_groups.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Groupsoperationedgegroupcreatecreate An Edgegroup](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupCreateCreate-an-EdgeGroup.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Groupsoperationedgegroupdeletedeletes An Edgegroup](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupDeleteDeletes-an-EdgeGroup.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Groupsoperationedgegroupinspectinspects An Edgegroup](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupInspectInspects-an-EdgeGroup.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Groupsoperationedgegrouplistlist Edgegroups](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupListlist-EdgeGroups.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Groupsoperationedgegroupupdateupdates An Edgegroup](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupUpdateUpdates-an-EdgeGroup.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsedge Jobs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsedge_jobs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobcreatefilecreate An Edgejob From A File](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobCreateFileCreate-an-EdgeJob-from-a-file.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobcreatestringcreate An Edgejob From A Text](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobCreateStringCreate-an-EdgeJob-from-a-text.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobdeletedelete An Edgejob](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobDeleteDelete-an-EdgeJob.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobfilefetch A File Of An Edgejob](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobFileFetch-a-file-of-an-EdgeJob.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobinspectinspect An Edgejob](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobInspectInspect-an-EdgeJob.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejoblistfetch Edgejobs List](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobListFetch-EdgeJobs-list.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobtasklogsinspectfetch The Log For A Specifc Task On An Edgejob](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobTaskLogsInspectFetch-the-log-for-a-specifc-task-on-an-EdgeJob.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobtasksclearclear The Log For A Specifc Task On An Edgejob](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobTasksClearClear-the-log-for-a-specifc-task-on-an-EdgeJob.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobtaskscollectcollect The Log For A Specifc Task On An Edgejob](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobTasksCollectCollect-the-log-for-a-specifc-task-on-an-EdgeJob.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobtaskslistfetch The List Of Tasks On An Edgejob](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobTasksListFetch-the-list-of-tasks-on-an-EdgeJob.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Jobsoperationedgejobupdateupdate An Edgejob](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobUpdateUpdate-an-EdgeJob.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksedge Stacks](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksedge_stacks.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackcreatefilecreate An Edgestack From File](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackCreateFileCreate-an-EdgeStack-from-file.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackcreaterepositorycreate An Edgestack From A Git Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackCreateRepositoryCreate-an-EdgeStack-from-a-git-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackcreatestringcreate An Edgestack From A Text](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackCreateStringCreate-an-EdgeStack-from-a-text.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackdeletedelete An Edgestack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackDeleteDelete-an-EdgeStack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackfilefetches The Stack File For An Edgestack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackFileFetches-the-stack-file-for-an-EdgeStack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackinspectinspect An Edgestack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackInspectInspect-an-EdgeStack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestacklistfetches The List Of Edgestacks](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackListFetches-the-list-of-EdgeStacks.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestacklogscollectschedule The Collection Of Logs For A Given Endpoint And Edge Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackLogsCollectSchedule-the-collection-of-logs-for-a-given-endpoint-and-edge-stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestacklogsdeletedeletes The Available Logs For A Given Edge Stack And Endpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackLogsDeleteDeletes-the-available-logs-for-a-given-edge-stack-and-endpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestacklogsdownloaddownloads The Available Logs For A Given Edge Stack And Endpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackLogsDownloadDownloads-the-available-logs-for-a-given-edge-stack-and-endpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestacklogsstatusgetgets The Status Of The Log Collection For A Given Edgestack And Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackLogsStatusGetGets-the-status-of-the-log-collection-for-a-given-edgestack-and-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackparseregistriesparse Registries From A Stack File](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackParseRegistriesParse-registries-from-a-stack-file.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackstaggerstatusinspectinspect An Edgestacks Parallel Update Status](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackStaggerStatusInspectInspect-an-EdgeStacks-parallel-update-status.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackstatusupdateupdate An Edgestack Status](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackStatusUpdateUpdate-an-EdgeStack-status.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackupdateupdate An Edgestack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackUpdateUpdate-an-EdgeStack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stacksoperationedgestackupdatefromgitupdate Git Configuration And Pulls The Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationedgeStackUpdateFromGitUpdate-git-configuration-and-pulls-the-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Stackspaths1Endpoints1Id1Edge1Stacks1Stackidgetinspect An Edge Stack For An Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stackspaths1endpoints1id1edge1stacks1stackIdgetInspect-an-Edge-Stack-for-an-EnvironmentEndpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Templatesedge Templates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_templatesedge_templates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesedge Update Schedules](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesedge_update_schedules.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationedgeupdatepreviousversionsfetches The Previous Versions Of Updated Agents](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdatePreviousVersionsFetches-the-previous-versions-of-updated-agents.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationedgeupdatescheduleactivescheduleslistfetches The List Of Active Edge Update Schedules](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleActiveSchedulesListFetches-the-list-of-Active-Edge-Update-Schedules.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationedgeupdateschedulecreatecreates A Scheduled Remote Update Procedure For Edge Agents](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleCreateCreates-a-scheduled-remote-update-procedure-for-Edge-agents.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationedgeupdatescheduledeletedeletes An Edge Update Schedule](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleDeleteDeletes-an-Edge-Update-Schedule.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationedgeupdatescheduleinforeturns Informations The Help Create Edge Update Schedules](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleInfoReturns-informations-the-help-create-edge-update-schedules.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationedgeupdatescheduleinspectreturns The Edge Update Schedule With The Given Id](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleInspectReturns-the-Edge-Update-Schedule-with-the-given-ID.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationedgeupdateschedulelistfetches The List Of Edge Update Schedules](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleListFetches-the-list-of-Edge-Update-Schedules.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationedgeupdatescheduleupdateupdate A Scheduled Remote Update Procedure For Edge Agents](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleUpdateUpdate-a-scheduled-remote-update-procedure-for-Edge-agents.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedge Update Schedulesoperationremoteupdatesagentversionsfetches The Supported Versions Of The Agent To Updaterollback](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationRemoteUpdatesAgentVersionsFetches-the-supported-versions-of-the-agent-to-updaterollback.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedgeedge](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedgeedge.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedgepaths1Endpoints1Edge1Generate Keypostgenerate An Edgekey](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedgepaths1endpoints1edge1generate-keypostGenerate-an-EdgeKey.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedgepaths1Endpoints1Id1Edge1Jobs1Jobid1Logspostupdate The Logs Collected From An Edge Job](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedgepaths1endpoints1id1edge1jobs1jobID1logspostUpdate-the-logs-collected-from-an-Edge-Job.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagedgepaths1Endpoints1Id1Edge1Stacks1Stackidgetinspect An Edge Stack For An Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedgepaths1endpoints1id1edge1stacks1stackIdgetInspect-an-Edge-Stack-for-an-EnvironmentEndpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpoint Groupsendpoint Groups](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsendpoint_groups.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpoint Groupsoperationendpointgroupaddendpointadd An Environmentendpoint To An Environmentendpoint Group](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupAddEndpointAdd-an-environmentendpoint-to-an-environmentendpoint-group.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpoint Groupsoperationendpointgroupdeleteendpointremoves Environmentendpoint From An Environmentendpoint Group](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupDeleteEndpointRemoves-environmentendpoint-from-an-environmentendpoint-group.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpoint Groupsoperationendpointgroupdeleteremove An Environmentendpoint Group](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupDeleteRemove-an-environmentendpoint-group.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpoint Groupsoperationendpointgrouplistlist Environmentendpoint Groups](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupListList-EnvironmentEndpoint-groups.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpoint Groupsoperationendpointgroupupdateupdate An Environmentendpoint Group](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupUpdateUpdate-an-environmentendpoint-group.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpoint Groupspaths1Endpoint Groups1Idgetinspect An Environmentendpoint Group](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupspaths1endpoint_groups1idgetInspect-an-EnvironmentEndpoint-group.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpoint Groupspaths1Endpoint Groupspostcreate An Environmentendpoint Group](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupspaths1endpoint_groupspostCreate-an-EnvironmentEndpoint-Group.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsendpoints](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsendpoints.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationagentversionslist Agent Versions](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationAgentVersionsList-agent-versions.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointassociationdeletede Association An Edge Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointAssociationDeleteDe-association-an-edge-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointcreatecreate A New Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointCreateCreate-a-new-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointcreateglobalkeycreate Or Retrieve The Endpoint For An Edgeid](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointCreateGlobalKeyCreate-or-retrieve-the-endpoint-for-an-EdgeID.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointdeletebatchdeprecatedremove Multiple Environments  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointDeleteBatchDeprecatedRemove-multiple-environments--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointdeletebatchremove Multiple Environments](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointDeleteBatchRemove-multiple-environments.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointdeleteremove An Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointDeleteRemove-an-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointedgestatusinspectget Environmentendpoint Status](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointEdgeStatusInspectGet-environmentendpoint-status.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointgetchartsget Environmentendpoint Charts To Install](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointGetChartsGet-environmentendpoint-charts-to-install.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointinspectinspect An Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointInspectInspect-an-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointlistlist Environmentsendpoints](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointListList-environmentsendpoints.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointmtlsagentcertificateerrorget An Agentendpoint Mtls Certificate](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointMTLSAgentCertificateErrorGet-an-agentendpoint-mTLS-certificate.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointmtlscertificateget An Environmentendpoint Mtls Certificate](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointMTLSCertificateGet-an-environmentendpoint-mTLS-certificate.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointsettingsupdateupdate Settings For An Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointSettingsUpdateUpdate-settings-for-an-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointsnapshotsnapshots An Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointSnapshotSnapshots-an-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointsnapshotssnapshot All Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointSnapshotsSnapshot-all-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointupdatechartstatusesupdate Environmentendpoint Policy Chart Installation Statuses](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointUpdateChartStatusesUpdate-environmentendpoint-policy-chart-installation-statuses.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointupdaterelationsupdate Relations For A List Of Environments](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointUpdateRelationsUpdate-relations-for-a-list-of-environments.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointupdateupdate An Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointUpdateUpdate-an-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationtrustedgeendpointsassociate One Or More Edge Environments In The Waiting Room To Environments](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationTrustEdgeEndpointsAssociate-one-or-more-Edge-environments-in-the-waiting-room-to-environments.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointdockerhubstatusfetch Docker Pull Limits](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointDockerhubStatusfetch-docker-pull-limits.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointedgeasyncget Environmentendpoint Status](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointEdgeAsyncGet-environmentendpoint-status.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointforceupdateserviceforce Update A Docker Service](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointForceUpdateServiceforce-update-a-docker-service.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointregistrieslistlist Registries On Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointRegistriesListList-Registries-on-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationendpointregistryaccessupdate Registry Access For Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointRegistryAccessupdate-registry-access-for-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationnamespacesaccessupdateupdate Namespace Access For A Given Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationnamespacesAccessUpdateUpdate-namespace-access-for-a-given-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationsnapshotcontainerinspectfetch Container From A Snapshot](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationsnapshotContainerInspectFetch-container-from-a-snapshot.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationsnapshotcontainerslistfetch Containers List From A Snapshot](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationsnapshotContainersListFetch-containers-list-from-a-snapshot.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointsoperationsnapshotinspectfetch Latest Snapshot Of Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationsnapshotInspectFetch-latest-snapshot-of-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointspaths1Endpoints1Edge1Generate Keypostgenerate An Edgekey](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointspaths1endpoints1edge1generate-keypostGenerate-an-EdgeKey.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointspaths1Endpoints1Id1Docker1V21Browse1Putpostupload A File Under A Specific Path On The File System Of An Environment Endpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointspaths1endpoints1id1docker1v21browse1putpostUpload-a-file-under-a-specific-path-on-the-file-system-of-an-environment-endpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointspaths1Endpoints1Id1Edge1Jobs1Jobid1Logspostupdate The Logs Collected From An Edge Job](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointspaths1endpoints1id1edge1jobs1jobID1logspostUpdate-the-logs-collected-from-an-Edge-Job.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagendpointspaths1Endpoints1Id1Edge1Stacks1Stackidgetinspect An Edge Stack For An Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointspaths1endpoints1id1edge1stacks1stackIdgetInspect-an-Edge-Stack-for-an-EnvironmentEndpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taggitopsgitops](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsgitops.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taggitopsoperationgitoperationrepofilepreviewpreview The Content Of Target File In The Git Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsoperationGitOperationRepoFilePreviewpreview-the-content-of-target-file-in-the-git-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taggitopsoperationgitoperationrepofilessearchsearch The File Path From A Git Repository Files With Specified Extensions](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsoperationGitOperationRepoFilesSearchSearch-the-file-path-from-a-git-repository-files-with-specified-extensions.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taggitopsoperationgitoperationrepohelmvaluespreview Merged Helm Values Files From Git Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsoperationGitOperationRepoHelmValuesPreview-merged-Helm-values-files-from-git-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taggitopsoperationgitoperationreporefslist The Refs Of A Git Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsoperationGitOperationRepoRefsList-the-refs-of-a-git-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmhelm](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmhelm.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmdeletedelete Helm Release](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmDeleteDelete-Helm-Release.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmgetget A Helm Release](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmGetGet-a-helm-release.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmgethistoryget A Historical List Of Releases](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmGetHistoryGet-a-historical-list-of-releases.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmgitdryrunhelm Git Dry Run](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmGitDryRunHelm-Git-Dry-Run.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelminstallinstall Helm Chart](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmInstallInstall-Helm-Chart.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmlistlist Helm Releases](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmListList-Helm-Releases.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmreposearchsearch Helm Charts](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmRepoSearchSearch-Helm-Charts.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmrollbackrollback A Helm Release](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmRollbackRollback-a-helm-release.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmshowshow Helm Chart Information](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmShowShow-Helm-Chart-Information.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmuserrepositorieslistlist A Users Helm Repositories](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmUserRepositoriesListList-a-users-helm-repositories.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmuserrepositorycreatecreate A User Helm Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmUserRepositoryCreateCreate-a-user-helm-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taghelmoperationhelmuserrepositorydeletedelete A Users Helm Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmUserRepositoryDeleteDelete-a-users-helm-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagintelintel](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagintelintel.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taginteloperationdeviceactionexecute Out Of Band Action On An Amt Managed Device  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationDeviceActionExecute-out-of-band-action-on-an-AMT-managed-device--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taginteloperationdevicefeaturesenable Features On An Amt Managed Device  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationDeviceFeaturesEnable-features-on-an-AMT-managed-device--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taginteloperationopenamtconfigureenable Portainers Openamt Capabilities  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationOpenAMTConfigureEnable-Portainers-OpenAMT-capabilities--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taginteloperationopenamtdevicesfetch Openamt Managed Devices Information For Endpoint  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationOpenAMTDevicesFetch-OpenAMT-managed-devices-information-for-endpoint--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taginteloperationopenamthostinforequest Openamt Info From A Node  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationOpenAMTHostInfoRequest-OpenAMT-info-from-a-node--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taginteloperationopenamtactivateactivate Openamt Device And Associate To Agent Endpoint  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationopenAMTActivateActivate-OpenAMT-device-and-associate-to-agent-endpoint--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaaskaas](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaaskaas.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationaddnodesadd Nodes To The Cluster Scale Up.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationaddNodesAdd-nodes-to-the-cluster-scale-up..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationkaasversionget The Current Cluster Version.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationkaasVersionGet-the-current-cluster-version..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationmicrok8Sgetaddonsget A List Of Addons Which Are Installed In A Microk8S Cluster.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationmicrok8sGetAddonsGet-a-list-of-addons-which-are-installed-in-a-MicroK8s-cluster..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationmicrok8Sgetnodestatusget The Microk8S Status For A Control Plane Node.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationmicrok8sGetNodeStatusGet-the-MicroK8s-status-for-a-control-plane-node..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationmicrok8Supdateaddonsget A List Of Addons Which Are Installed In A Microk8S Cluster.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationmicrok8sUpdateAddonsGet-a-list-of-addons-which-are-installed-in-a-MicroK8s-cluster..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationproviderinfoget Information About The Provisioning Options For A Cloud Provider.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationproviderInfoGet-information-about-the-provisioning-options-for-a-cloud-provider..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationprovisionclusteramazonprovision A New Amazon Eks And Create An Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationprovisionClusterAmazonProvision-a-new-Amazon-EKS-and-create-an-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationprovisionclusterazureprovision A New Microsoft Azure Cluster And Create An Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationprovisionClusterAzureProvision-a-new-Microsoft-Azure-cluster-and-create-an-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationprovisionclustergkeprovision A New Google Kubernetes Gke Cluster And Create An Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationprovisionClusterGKEProvision-a-new-Google-Kubernetes-GKE-cluster-and-create-an-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationprovisionclusterprovision A New Civo Linode Or Digital Ocean Cluster And Create An Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationprovisionClusterProvision-a-new-CIVO-Linode-or-Digital-Ocean-cluster-and-create-an-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationremovenodesremove Nodes From The Cluster And Uninstall Microk8S From Them.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationremoveNodesRemove-nodes-from-the-cluster-and-uninstall-MicroK8s-from-them..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationtestsshtest Ssh Connection To Nodes](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationtestSSHTest-SSH-connection-to-nodes.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkaasoperationupgradeupgrade The Cluster To The Next Stable Kubernetes Version.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationupgradeUpgrade-the-cluster-to-the-next-stable-kubernetes-version..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkuberneteskubernetes](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkuberneteskubernetes.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationcreatekubernetesingresscreate An Ingress](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationCreateKubernetesIngressCreate-an-Ingress.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationcreatekubernetesnamespacecreate A Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationCreateKubernetesNamespaceCreate-a-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationcreatekubernetesservicecreate A Service](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationCreateKubernetesServiceCreate-a-service.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeleteclusterrolebindingsdelete Cluster Role Bindings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteClusterRoleBindingsDelete-cluster-role-bindings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeleteclusterrolesdelete Cluster Roles](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteClusterRolesDelete-cluster-roles.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeletecronjobsdelete Cron Jobs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteCronJobsDelete-Cron-Jobs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeletejobsdelete Jobs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteJobsDelete-Jobs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeletekubernetesingressesdelete One Or More Ingresses](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteKubernetesIngressesDelete-one-or-more-Ingresses.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeletekubernetesnamespacedelete A Kubernetes Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteKubernetesNamespaceDelete-a-kubernetes-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeletekubernetesservicesdelete Services](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteKubernetesServicesDelete-services.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeleterolebindingsdelete Role Bindings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteRoleBindingsDelete-role-bindings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeleterolesdelete Roles](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteRolesDelete-roles.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeleteserviceaccountsdelete Service Accounts](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteServiceAccountsDelete-service-accounts.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdescriberesourceget A Description Of A Kubernetes Resource](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDescribeResourceGet-a-description-of-a-kubernetes-resource.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesapplicationget An Application By Name In A Specific Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesApplicationGet-an-application-by-name-in-a-specific-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesapplicationsget A List Of Applications Across All Namespaces In The Cluster. If The Nodename Is Provided It Will Return The Applications Running On That Node.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesApplicationsGet-a-list-of-applications-across-all-namespaces-in-the-cluster.-If-the-nodeName-is-provided-it-will-return-the-applications-running-on-that-node..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesclusteringressescountget Ingresses Count](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesClusterIngressesCountGet-Ingresses-count.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesclusteringressesget Kubernetes Ingresses At The Cluster Level](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesClusterIngressesGet-kubernetes-ingresses-at-the-cluster-level.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesclusterrolebindingsget A List Of Kubernetes Cluster Role Bindings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesClusterRoleBindingsGet-a-list-of-kubernetes-cluster-role-bindings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesclusterrolesget A List Of Kubernetes Cluster Roles](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesClusterRolesGet-a-list-of-kubernetes-cluster-roles.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesconfigmapscountget Configmaps Count](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesConfigMapsCountGet-ConfigMaps-count.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesconfigmapsget A List Of Configmaps](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesConfigMapsGet-a-list-of-ConfigMaps.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesingresscontrollersget A List Of Ingress Controllers](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesIngressControllersGet-a-list-of-ingress-controllers.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesingressesget A List Of Ingresses](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesIngressesGet-a-list-of-Ingresses.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesservicescountget Services Count](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesServicesCountGet-services-count.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesvolumesget Kubernetes Volumes Within The Given Portainer Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesVolumesGet-Kubernetes-volumes-within-the-given-Portainer-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetapplicationsresourcesget The Total Cpu Cores And Memory Requests Mb And Limits Of All Applications Across All Namespaces](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetApplicationsResourcesGet-the-total-CPU-cores-and-memory-requests-MB-and-limits-of-all-applications-across-all-namespaces.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesconfigmapget A Configmap](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesConfigMapGet-a-ConfigMap.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetescronjobsget A List Of Kubernetes Cron Jobs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesCronJobsGet-a-list-of-kubernetes-Cron-Jobs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesdashboardget The Dashboard Summary Data](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesDashboardGet-the-dashboard-summary-data.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesingresscontrollersbynamespaceget A List Ingress Controllers By Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesIngressControllersByNamespaceGet-a-list-ingress-controllers-by-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesingressget An Ingress By Name](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesIngressGet-an-Ingress-by-name.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesjobsget A List Of Kubernetes Jobs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesJobsGet-a-list-of-kubernetes-Jobs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesmaxresourcelimitsget Max Cpu And Memory Limits Of All Nodes Within K8S Cluster](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMaxResourceLimitsGet-max-CPU-and-memory-limits-of-all-nodes-within-k8s-cluster.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesmetricsforallnodesget A List Of Nodes With Their Live Metrics](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMetricsForAllNodesGet-a-list-of-nodes-with-their-live-metrics.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesmetricsforallpodsget A List Of Pods With Their Live Metrics](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMetricsForAllPodsGet-a-list-of-pods-with-their-live-metrics.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesmetricsfornodeget Live Metrics For A Node](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMetricsForNodeGet-live-metrics-for-a-node.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesmetricsforpodget Live Metrics For A Pod](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMetricsForPodGet-live-metrics-for-a-pod.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesnamespaceget Namespace Details](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesNamespaceGet-namespace-details.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesnamespacescountget The Total Number Of Kubernetes Namespaces Within The Given Portainer Environment.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesNamespacesCountGet-the-total-number-of-kubernetes-namespaces-within-the-given-Portainer-environment..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesnamespacesget A List Of Namespaces](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesNamespacesGet-a-list-of-namespaces.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesnodeslimitsget Cpu And Memory Limits Of All Nodes Within K8S Cluster.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesNodesLimitsGet-CPU-and-memory-limits-of-all-nodes-within-k8s-cluster..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesrbacstatuscheck If Rbac Is Enabled](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesRBACStatusCheck-if-RBAC-is-enabled.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesrolebindingsget A List Of Kubernetes Role Bindings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesRoleBindingsGet-a-list-of-kubernetes-role-bindings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesrolesget A List Of Kubernetes Roles](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesRolesGet-a-list-of-kubernetes-roles.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetessecretget A Secret](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesSecretGet-a-Secret.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetessecretscountget Secrets Count](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesSecretsCountGet-Secrets-count.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetessecretsget A List Of Secrets](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesSecretsGet-a-list-of-Secrets.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesserviceaccountsget A List Of Kubernetes Service Accounts](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesServiceAccountsGet-a-list-of-kubernetes-service-accounts.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesservicesbynamespaceget A List Of Services For A Given Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesServicesByNamespaceGet-a-list-of-services-for-a-given-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesservicesget A List Of Services](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesServicesGet-a-list-of-services.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesvolumeget A Kubernetes Volume Within The Given Portainer Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesVolumeGet-a-Kubernetes-volume-within-the-given-Portainer-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesvolumesinnamespaceget Kubernetes Volumes Within A Namespace In The Given Portainer Environment](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesVolumesInNamespaceGet-Kubernetes-volumes-within-a-namespace-in-the-given-Portainer-environment.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationkubernetesnamespacestogglesystemtoggle The System State For A Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationKubernetesNamespacesToggleSystemToggle-the-system-state-for-a-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationupdatekubernetesingresscontrollersbynamespaceupdate Blockunblock Ingress Controllers By Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesIngressControllersByNamespaceUpdate-blockunblock-ingress-controllers-by-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationupdatekubernetesingresscontrollersupdate Blockunblock Ingress Controllers](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesIngressControllersUpdate-blockunblock-ingress-controllers.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationupdatekubernetesingressupdate An Ingress](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesIngressUpdate-an-Ingress.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationupdatekubernetesnamespacedeprecatedupdate A Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesNamespaceDeprecatedUpdate-a-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationupdatekubernetesnamespaceupdate A Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesNamespaceUpdate-a-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationupdatekubernetesserviceupdate A Service](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesServiceUpdate-a-service.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeletekubernetesclusterscopedcustomresourcedelete A Cluster Scoped Kubernetes Custom Resource](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationdeleteKubernetesClusterScopedCustomResourceDelete-a-cluster-scoped-kubernetes-Custom-Resource.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeletekubernetescustomresourcedefinitiondelete A Kubernetes Custom Resource Definition](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationdeleteKubernetesCustomResourceDefinitionDelete-a-kubernetes-Custom-Resource-Definition.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdeletekubernetesnamespacedcustomresourcedelete A Namespaced Kubernetes Custom Resource](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationdeleteKubernetesNamespacedCustomResourceDelete-a-namespaced-kubernetes-Custom-Resource.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationdrainnodedrain A Kubernetes Node](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationdrainNodeDrain-a-Kubernetes-node.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesapplicationscountget Applications Count](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetAllKubernetesApplicationsCountGet-Applications-count.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkuberneteseventsgets Kubernetes Events](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetAllKubernetesEventsGets-kubernetes-events.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetallkubernetesvolumescountget The Total Number Of Kubernetes Volumes Within The Given Portainer Environment.](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetAllKubernetesVolumesCountGet-the-total-number-of-kubernetes-volumes-within-the-given-Portainer-environment..md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesallcustomresourcesget A List Of Kubernetes Custom Resources](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesAllCustomResourcesGet-a-list-of-kubernetes-Custom-Resources.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesclusterscopedcustomresourceget A Cluster Scoped Kubernetes Custom Resource](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesClusterScopedCustomResourceGet-a-cluster-scoped-kubernetes-Custom-Resource.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetescustomresourcedefinitionget A Kubernetes Custom Resource Definition](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesCustomResourceDefinitionGet-a-kubernetes-Custom-Resource-Definition.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetescustomresourcedefinitionsget A List Of Kubernetes Custom Resource Definitions](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesCustomResourceDefinitionsGet-a-list-of-kubernetes-Custom-Resource-Definitions.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkuberneteseventsfornamespacegets Kubernetes Events For Namespace](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesEventsForNamespaceGets-kubernetes-events-for-namespace.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetesnamespacedcustomresourceget A List Of Kubernetes Custom Resources](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesNamespacedCustomResourceGet-a-list-of-kubernetes-Custom-Resources.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationgetkubernetespodsecurityruleget Pod Security Rule Within K8S Cluster If Not Found The Frontend Will Create A Default](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesPodSecurityRuleGet-Pod-Security-Rule-within-k8s-cluster-if-not-found-the-frontend-will-create-a-default.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationrestartkubernetesapplicationrestart A Kubernetes Application](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationrestartKubernetesApplicationRestart-a-Kubernetes-application.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagkubernetesoperationupdatek8Spodsecurityruleupdate Pod Security Rule Within K8S Cluster](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationupdateK8sPodSecurityRuleUpdate-Pod-Security-Rule-within-k8s-cluster.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagldapldap](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapldap.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagldapoperationldapadmingroupsfetch Ldap Admin Groups](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPAdminGroupsFetch-LDAP-admin-groups.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagldapoperationldapchecktest Ldap Connectivity](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPCheckTest-LDAP-connectivity.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagldapoperationldapgroupssearch Ldap Groups](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPGroupsSearch-LDAP-Groups.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagldapoperationldaptestlogintest Login To Ldap Server](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPTestLoginTest-Login-to-ldap-server.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagldapoperationldapuserssearch Ldap Users](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPUsersSearch-LDAP-Users.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taglicenselicense](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenselicense.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taglicenseoperationlicensesattachattaches A List Of Licenses To Portainer](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenseoperationlicensesAttachattaches-a-list-of-licenses-to-Portainer.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taglicenseoperationlicensesdeletedelete License From Portainer Instance](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenseoperationlicensesDeletedelete-license-from-portainer-instance.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taglicenseoperationlicensesinfosummarizes Licenses On Portainer](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenseoperationlicensesInfosummarizes-licenses-on-Portainer.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taglicenseoperationlicenseslistfetches The List Of Licenses On Portainer](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenseoperationlicensesListfetches-the-list-of-licenses-on-Portainer.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagmetricsmetrics](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagmetricsmetrics.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagmotdmotd](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagmotdmotd.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagmotdoperationmotdfetches The Message Of The Day](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagmotdoperationMOTDfetches-the-message-of-the-day.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityobservability](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityobservability.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationcreatesilencecreate An Alert Silence](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationCreateSilenceCreate-an-alert-silence.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationdeletealertruledelete An Alert Rule](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationDeleteAlertRuleDelete-an-alert-rule.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationdeletesilencedelete An Alert Silence](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationDeleteSilenceDelete-an-alert-silence.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationgetalertruleget An Alert Rule By Id](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAlertRuleGet-an-alert-rule-by-ID.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationgetalertingsettingsget Alerting Settings By Id](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAlertingSettingsGet-alerting-settings-by-ID.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationgetalertsget Active Or Silenced Alerts](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAlertsGet-active-or-silenced-alerts.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationgetallalertrulesget All Alert Rules](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAllAlertRulesGet-all-alert-rules.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationgetallalertingsettingsget All Alerting Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAllAlertingSettingsGet-all-alerting-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationtestalertmanagerconnectivitytest Alertmanager Connectivity](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationTestAlertManagerConnectivityTest-AlertManager-connectivity.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationupdatealertruleupdate An Alert Rule](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationUpdateAlertRuleUpdate-an-alert-rule.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagobservabilityoperationupdatealertingsettingsupdate Alerting Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationUpdateAlertingSettingsUpdate-alerting-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicyconflictsget Policy Conflicts Preview](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyConflictsGet-policy-conflicts-preview.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicycreatecreate A New Policy](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyCreateCreate-a-new-policy.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicydeletedelete A Policy](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyDeleteDelete-a-policy.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicyinspectinspect A Policy](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyInspectInspect-a-policy.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicylistlist Policies](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyListList-policies.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicymetadataget Policy Metadata](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyMetadataGet-policy-metadata.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicytemplateinspectinspect A Policy Template](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyTemplateInspectInspect-a-policy-template.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicytemplatelistlist Policy Templates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyTemplateListList-policy-templates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciesoperationpolicyupdateupdate A Policy](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyUpdateUpdate-a-policy.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagpoliciespolicies](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciespolicies.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationregistryconfigureconfigures A Registry](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryConfigureConfigures-a-registry.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationregistrycreatecreate A New Registry](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryCreateCreate-a-new-registry.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationregistrydeleteremove A Registry](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryDeleteRemove-a-registry.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationregistryinspectinspect A Registry](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryInspectInspect-a-registry.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationregistrylistlist Registries](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryListList-Registries.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationregistrypingtest Registry Connection](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryPingTest-registry-connection.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationregistryupdateupdate A Registry](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryUpdateUpdate-a-registry.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationrepositorytagsdeletedelete Repository Tags](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRepositoryTagsDeleteDelete-repository-tags.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationecrdeleterepositorydelete Ecr Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationecrDeleteRepositoryDelete-ECR-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesoperationecrdeletetagsdelete Tags](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationecrDeleteTagsDelete-tags.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagregistriesregistries](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesregistries.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagresource Controlsoperationresourcecontrolcreatecreate A New Resource Control](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagresource_controlsoperationResourceControlCreateCreate-a-new-resource-control.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagresource Controlsoperationresourcecontroldeleteremove A Resource Control](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagresource_controlsoperationResourceControlDeleteRemove-a-resource-control.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagresource Controlsoperationresourcecontrolupdateupdate A Resource Control](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagresource_controlsoperationResourceControlUpdateUpdate-a-resource-control.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagresource Controlsresource Controls](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagresource_controlsresource_controls.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagrolesoperationrolelistlist Roles](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagrolesoperationRoleListList-roles.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagrolesroles](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagrolesroles.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationdefaultregistryupdateupdate Portainer Default Registry Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationDefaultRegistryUpdateUpdate-Portainer-default-registry-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingsadditionalfunctionalityinspectretrieve Portainer Additional Functionality Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsAdditionalFunctionalityInspectRetrieve-Portainer-additional-functionality-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingsadditionalfunctionalityupdateupdate Portainer Additional Functionality Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsAdditionalFunctionalityUpdateUpdate-Portainer-additional-functionality-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingsedgemtlscacertificatesretrieve Portainer Edge Mtls Ca Certificates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsEdgeMTLSCACertificatesRetrieve-Portainer-Edge-MTLS-CA-Certificates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingsedgemtlscertificatesretrieve Portainer Edge Mtls Certificates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsEdgeMTLSCertificatesRetrieve-Portainer-Edge-MTLS-Certificates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingsexperimentalinspectretrieve Portainer Experimental Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsExperimentalInspectRetrieve-Portainer-experimental-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingsexperimentalupdateupdate Portainer Experimental Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsExperimentalUpdateUpdate-Portainer-experimental-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingsinspectretrieve Portainer Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsInspectRetrieve-Portainer-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingspublicretrieve Portainer Public Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsPublicRetrieve-Portainer-public-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingsoperationsettingsupdateupdate Portainer Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsUpdateUpdate-Portainer-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsettingssettings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingssettings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagssloperationsslinspectinspect The Ssl Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagssloperationSSLInspectInspect-the-ssl-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagssloperationsslupdateupdate The Ssl Settings](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagssloperationSSLUpdateUpdate-the-ssl-settings.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsslssl](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsslssl.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationedgestackwebhookinvokewebhook For Triggering Edge Stack Updates From Git](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationEdgeStackWebhookInvokeWebhook-for-triggering-edge-stack-updates-from-git.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackassociateassociate An Orphaned Stack To A New Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackAssociateAssociate-an-orphaned-stack-to-a-new-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatedockerstandalonefiledeploy A New Compose Stack From A File](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerStandaloneFileDeploy-a-new-compose-stack-from-a-file.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatedockerstandalonerepositorydeploy A New Compose Stack From Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerStandaloneRepositoryDeploy-a-new-compose-stack-from-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatedockerstandalonestringdeploy A New Compose Stack From A Text](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerStandaloneStringDeploy-a-new-compose-stack-from-a-text.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatedockerswarmfiledeploy A New Swarm Stack From A File](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerSwarmFileDeploy-a-new-swarm-stack-from-a-file.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatedockerswarmrepositorydeploy A New Swarm Stack From A Git Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerSwarmRepositoryDeploy-a-new-swarm-stack-from-a-git-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatedockerswarmstringdeploy A New Swarm Stack From A Text](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerSwarmStringDeploy-a-new-swarm-stack-from-a-text.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatekubernetesfiledeploy A New Kubernetes Stack From A File](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateKubernetesFileDeploy-a-new-kubernetes-stack-from-a-file.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatekubernetesgitdeploy A New Kubernetes Stack From A Git Repository](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateKubernetesGitDeploy-a-new-kubernetes-stack-from-a-git-repository.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackcreatekubernetesurldeploy A New Kubernetes Stack From A Url](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateKubernetesUrlDeploy-a-new-kubernetes-stack-from-a-url.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackdeletekubernetesbynameremove Kubernetes Stacks By Name](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackDeleteKubernetesByNameRemove-Kubernetes-stacks-by-name.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackdeleteremove A Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackDeleteRemove-a-stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackfileinspectretrieve The Content Of The Stack File For The Specified Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackFileInspectRetrieve-the-content-of-the-Stack-file-for-the-specified-stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackgitredeployredeploy A Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackGitRedeployRedeploy-a-stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackinspectinspect A Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackInspectInspect-a-stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstacklistlist Stacks](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackListList-stacks.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackmigratemigrate A Stack To Another Environmentendpoint](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackMigrateMigrate-a-stack-to-another-environmentendpoint.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackstartstarts A Stopped Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackStartStarts-a-stopped-Stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackstopstops A Stopped Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackStopStops-a-stopped-Stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackupdategitupdate A Stacks Git Configs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackUpdateGitUpdate-a-stacks-Git-configs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackupdateupdate A Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackUpdateUpdate-a-stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackswebhookinvokewebhook For Triggering Stack Updates From Git](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStacksWebhookInvokeWebhook-for-triggering-stack-updates-from-git.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksoperationstackimagesstatusfetch Image Status For Stack](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationstackImagesStatusFetch-image-status-for-stack.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstacksstacks](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksstacks.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstatusoperationstatusinspectcheck Portainer Status  Deprecated](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstatusoperationStatusInspectCheck-Portainer-status--Deprecated.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagstatusstatus](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstatusstatus.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsupportoperationgetdebuglogstatusget Status Of The Global Debug Log](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsupportoperationGetDebugLogStatusGet-status-of-the-global-debug-log.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsupportoperationsetdebuglogstatusenables Or Disables The Global Debug Log](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsupportoperationSetDebugLogStatusEnables-or-disables-the-global-debug-log.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsupportoperationsupportbundledownloaddownload A Bundle Of Files To Help Support Diagnose Issues](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsupportoperationSupportBundleDownloadDownload-a-bundle-of-files-to-help-support-diagnose-issues.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsupportsupport](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsupportsupport.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsystemoperationsysteminforetrieve System Info](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemInfoRetrieve-system-info.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsystemoperationsystemnodescountretrieve The Count Of Nodes](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemNodesCountRetrieve-the-count-of-nodes.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsystemoperationsystemstatuscheck Portainer Status](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemStatusCheck-Portainer-status.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsystemoperationsystemupdateupdate Portainer To Latest Version](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemUpdateUpdate-Portainer-to-latest-version.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsystemoperationsystemversioncheck For Portainer Updates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemVersionCheck-for-portainer-updates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagsystemsystem](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemsystem.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagtagsoperationtagcreatecreate A New Tag](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtagsoperationTagCreateCreate-a-new-tag.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagtagsoperationtagdeleteremove A Tag](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtagsoperationTagDeleteRemove-a-tag.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagtagsoperationtaglistlist Tags](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtagsoperationTagListList-tags.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagtagstags](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtagstags.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteam Membershipsoperationteammembershipcreatecreate A New Team Membership](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipCreateCreate-a-new-team-membership.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteam Membershipsoperationteammembershipdeleteremove A Team Membership](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipDeleteRemove-a-team-membership.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteam Membershipsoperationteammembershiplistlist Team Memberships](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipListList-team-memberships.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteam Membershipsoperationteammembershipupdateupdate A Team Membership](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipUpdateUpdate-a-team-membership.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteam Membershipsoperationteammembershipslist Team Memberships](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipsList-team-memberships.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteam Membershipsteam Memberships](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsteam_memberships.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteamsoperationteamcreatecreate A New Team](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamCreateCreate-a-new-team.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteamsoperationteamdeleteremove A Team](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamDeleteRemove-a-team.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteamsoperationteaminspectinspect A Team](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamInspectInspect-a-team.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteamsoperationteamlistlist Teams](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamListList-teams.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteamsoperationteamupdateupdate A Team](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamUpdateUpdate-a-team.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagteamsteams](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsteams.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagtemplatesoperationtemplatefileget A Templates File](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtemplatesoperationTemplateFileGet-a-templates-file.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagtemplatesoperationtemplatelistlist Available Templates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtemplatesoperationTemplateListList-available-templates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagtemplatestemplates](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtemplatestemplates.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taguploadoperationuploadtlsupload Tls Files](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguploadoperationUploadTLSUpload-TLS-files.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taguploadupload](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguploadupload.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taguseractivityoperationauthlogscsvdownload Auth Logs As Csv](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityoperationAuthLogsCSVDownload-auth-logs-as-CSV.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taguseractivityoperationauthlogslistlist Auth Activity Logs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityoperationAuthLogsListList-auth-activity-logs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taguseractivityoperationlogscsvdownload User Activity Logs As Csv](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityoperationLogsCSVDownload-user-activity-logs-as-CSV.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taguseractivityoperationlogslistlist User Activity Logs](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityoperationLogsListList-user-activity-logs.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Taguseractivityuseractivity](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityuseractivity.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationcurrentuserendpointauthorizationsinspectinspect Environment Authorizations For The Current User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationCurrentUserEndpointAuthorizationsInspectInspect-environment-authorizations-for-the-current-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationcurrentuserinspectinspect The Current User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationCurrentUserInspectInspect-the-current-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuseradmincheckcheck Administrator Account Existence](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserAdminCheckCheck-administrator-account-existence.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuseradmininitinitialize Administrator Account](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserAdminInitInitialize-administrator-account.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationusercreatecreate A New User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserCreateCreate-a-new-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationusercreategitcredentialstore A Git Credential For A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserCreateGitCredentialStore-a-Git-Credential-for-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuserdeleteremove A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserDeleteRemove-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationusergenerateapikeygenerate An Api Key For A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserGenerateAPIKeyGenerate-an-API-key-for-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationusergetapikeysget All Api Keys For A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserGetAPIKeysGet-all-API-keys-for-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationusergetgitcredentialget The Specific Saved Git Credential For A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserGetGitCredentialGet-the-specific-saved-git-credential-for-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationusergetgitcredentialsget All Saved Git Credentials For A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserGetGitCredentialsGet-all-saved-git-credentials-for-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuserinspectinspect A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserInspectInspect-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuserlistlist Users](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserListList-users.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationusermembershipsinspectinspect A User Memberships](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserMembershipsInspectInspect-a-user-memberships.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationusernamespacesretrieves All K8S Namespaces For An User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserNamespacesRetrieves-all-k8s-namespaces-for-an-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuserremoveapikeyremove An Api Key Associated To A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserRemoveAPIKeyRemove-an-api-key-associated-to-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuserremovegitcredentialremove A Git Credential Associated To A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserRemoveGitCredentialRemove-a-git-credential-associated-to-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuserupdategitcredentialupdate A Git Credential Associated To A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserUpdateGitCredentialUpdate-a-git-credential-associated-to-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuserupdatepasswordupdate Password For A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserUpdatePasswordUpdate-password-for-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersoperationuserupdateupdate A User](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserUpdateUpdate-a-user.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagusersusers](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersusers.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebhookspaths1Webhooks1Id1Reassignputreassign A Webhook To Another Resource](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooks1id1reassignputReassign-a-webhook-to-another-resource.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebhookspaths1Webhooks1Iddeletedelete A Webhook](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooks1iddeleteDelete-a-webhook.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebhookspaths1Webhooks1Idpostexecute A Webhook](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooks1idpostExecute-a-webhook.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebhookspaths1Webhooks1Idputupdate A Webhook](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooks1idputUpdate-a-webhook.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebhookspaths1Webhooksgetlist Webhooks](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooksgetList-webhooks.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebhookspaths1Webhookspostcreate A Webhook](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhookspostCreate-a-webhook.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebhookswebhooks](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookswebhooks.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebsocketpaths1Websocket1Attachgetattach A Websocket](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1attachgetAttach-a-websocket.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebsocketpaths1Websocket1Execgetexecute A Websocket](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1execgetExecute-a-websocket.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebsocketpaths1Websocket1Kubernetes Shellgetexecute A Websocket On Kubectl Shell Pod](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1kubernetes-shellgetExecute-a-websocket-on-kubectl-shell-pod.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebsocketpaths1Websocket1Microk8S Shellgetconnect To A Remote Ssh Shell Via A Websocket](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1microk8s-shellgetConnect-to-a-remote-SSH-Shell-via-a-websocket.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebsocketpaths1Websocket1Podgetexecute A Websocket On Pod](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1podgetExecute-a-websocket-on-pod.md)
    - [Httpsapi Docs.Portainer.Ioeditioneeversion2.39.0Tagwebsocketwebsocket](reference/index/PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketwebsocket.md)
  - [PortainerEE API (2.39.0)](reference/index/PortainerEE-API-2.39.0.md)
  - [Index](reference/index/index.md)
  - [Table of Contents](reference/index/toc.md)
- 📁 **versions_ee_2.39.0.yaml/**
  - [Table of Contents](reference/versions_ee_2.39.0.yaml/toc.md)
  - [Versions Ee 2.39.0.Yaml Pt1](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt1.md)
  - [Versions Ee 2.39.0.Yaml Pt10](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt10.md)
  - [Versions Ee 2.39.0.Yaml Pt11](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt11.md)
  - [Versions Ee 2.39.0.Yaml Pt12](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt12.md)
  - [Versions Ee 2.39.0.Yaml Pt13](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt13.md)
  - [Versions Ee 2.39.0.Yaml Pt14](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt14.md)
  - [Versions Ee 2.39.0.Yaml Pt15](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt15.md)
  - [Versions Ee 2.39.0.Yaml Pt16](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt16.md)
  - [Versions Ee 2.39.0.Yaml Pt17](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt17.md)
  - [Versions Ee 2.39.0.Yaml Pt18](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt18.md)
  - [Versions Ee 2.39.0.Yaml Pt19](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt19.md)
  - [Versions Ee 2.39.0.Yaml Pt2](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt2.md)
  - [Versions Ee 2.39.0.Yaml Pt20](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt20.md)
  - [Versions Ee 2.39.0.Yaml Pt21](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt21.md)
  - [Versions Ee 2.39.0.Yaml Pt22](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt22.md)
  - [Versions Ee 2.39.0.Yaml Pt23](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt23.md)
  - [Versions Ee 2.39.0.Yaml Pt24](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt24.md)
  - [Versions Ee 2.39.0.Yaml Pt25](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt25.md)
  - [Versions Ee 2.39.0.Yaml Pt26](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt26.md)
  - [Versions Ee 2.39.0.Yaml Pt27](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt27.md)
  - [Versions Ee 2.39.0.Yaml Pt28](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt28.md)
  - [Versions Ee 2.39.0.Yaml Pt29](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt29.md)
  - [Versions Ee 2.39.0.Yaml Pt3](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt3.md)
  - [Versions Ee 2.39.0.Yaml Pt30](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt30.md)
  - [Versions Ee 2.39.0.Yaml Pt31](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt31.md)
  - [Versions Ee 2.39.0.Yaml Pt32](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt32.md)
  - [Versions Ee 2.39.0.Yaml Pt4](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt4.md)
  - [Versions Ee 2.39.0.Yaml Pt5](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt5.md)
  - [Versions Ee 2.39.0.Yaml Pt6](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt6.md)
  - [Versions Ee 2.39.0.Yaml Pt7](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt7.md)
  - [Versions Ee 2.39.0.Yaml Pt8](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt8.md)
  - [Versions Ee 2.39.0.Yaml Pt9](reference/versions_ee_2.39.0.yaml/versions_ee_2.39.0.yaml_pt9.md)
- [Admin Registries Browse](reference/admin_registries_browse.md)
- [Admin User Roles](reference/admin_user_roles.md)
- [Contribute Contribute](reference/contribute_contribute.md)
- [Whats New](reference/whats-new.md)

## 🤖 Agent Usage Guide

- When the user asks anything about **Portainer Agent Docs**, consult the reference files.
- Prefer exact quotes and direct links to the relevant file/section.
- The hierarchical TOC above makes navigation fast and intuitive.
- All images and assets are preserved so links work perfectly.
